Redd counts taken at the weir above Green and Red Fish Confluence.

Format

A csv file.

BROOD_YEAR

The year that the redd count was made.

SPAWNERS

Spawners estimated from the redd counts. See details.

FRACWILD

Fracwild wild. This is assumed to be 1 for this population due to the lack of any nearby hatcheries.

Details

Here are all the details.

Author

Jenny J.

Examples

data('Green-Fish-River') library(ggplot2) ggplot(out, aes(x=BROOD_YEAR, y=SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Green-Fish-River')