Description Usage Format Source
Learned food avoidances during pregnancy in Mysore, India, 2015
1 |
A data frame with 349 rows and 5 variables:
IDdouble Participant ID code
foodavoidcharacter Self-reported foods avoided during pregnancy
whotaughtcharacter Who told the participant to avoid that food
consequencecharacter Self-reported consequences of eating the food during pregnancy
kembara explainedcharacter A notes column on the participants understanding of local illness category kembara
http://somewhere.important.com/
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.