Green-Fish-River.RdRedd counts taken at the weir above Green and Red Fish Confluence.
A csv file.
The year that the redd count was made.
Spawners estimated from the redd counts. See details.
Fracwild wild. This is assumed to be 1 for this population due to the lack of any nearby hatcheries.
Here are all the details.
Jenny J.
data('Green-Fish-River') library(ggplot2) ggplot(out, aes(x=BROOD_YEAR, y=SPAWNERS)) + geom_point(na.rm = TRUE) + ggtitle('Green-Fish-River')